==> OOo_2.0.0_Win32Intel_solver_curvirgo_other.zip: solver/680/wntmsci10.pro/inc/com/sun/star/text/GraphicCrop.hpp <==
#ifndef _COM_SUN_STAR_TEXT_GRAPHICCROP_HPP_
#define _COM_SUN_STAR_TEXT_GRAPHICCROP_HPP_

#ifndef _SAL_CONFIG_H_
#include "sal/config.h"
#endif

#ifndef _COM_SUN_STAR_TEXT_GRAPHICCROP_HDL_
#include "com/sun/star/text/GraphicCrop.hdl"
#endif

#ifndef _COM_SUN_STAR_UNO_TYPE_HXX_
#include "com/sun/star/uno/Type.hxx"
#endif
#ifndef _SAL_TYPES_H_
#include "sal/types.h"
#endif
#ifndef _TYPELIB_TYPECLASS_H_
#include "typelib/typeclass.h"
#endif
#ifndef _TYPELIB_TYPEDESCRIPTION_H_
#include "typelib/typedescription.h"
#endif

namespace com { namespace sun { namespace star { namespace text {

inline GraphicCrop::GraphicCrop() SAL_THROW( () )
    : Top(0)
    , Bottom(0)
    , Left(0)
    , Right(0)
{
}

inline GraphicCrop::GraphicCrop(const ::sal_Int32& Top_, const ::sal_Int32& Bottom_, const ::sal_Int32& Left_, const ::sal_Int32& Right_) SAL_THROW( () )
    : Top(Top_)
    , Bottom(Bottom_)
    , Left(Left_)
    , Right(Right_)
{
}

} } } }

inline ::com::sun::star::uno::Type const & SAL_CALL getCppuType(::com::sun::star::text::GraphicCrop const *) {
    //TODO: On certain platforms with weak memory models, the following code can result in some threads observing that the_type points to garbage
    static ::typelib_TypeDescriptionReference * the_type = 0;
    if (the_type == 0) {
        ::typelib_static_type_init(&the_type, typelib_TypeClass_STRUCT, "com.sun.star.text.GraphicCrop");
    }
    return *reinterpret_cast< ::com::sun::star::uno::Type * >(&the_type);
}

#endif // _COM_SUN_STAR_TEXT_GRAPHICCROP_HPP_

==> OOo_2.0.3_Win32Intel_solver_curvirgo_other.zip: solver/680/wntmsci10.pro/inc/com/sun/star/text/GraphicCrop.hpp <==
#ifndef _COM_SUN_STAR_TEXT_GRAPHICCROP_HPP_
#define _COM_SUN_STAR_TEXT_GRAPHICCROP_HPP_

#ifndef _SAL_CONFIG_H_
#include "sal/config.h"
#endif

#ifndef _COM_SUN_STAR_TEXT_GRAPHICCROP_HDL_
#include "com/sun/star/text/GraphicCrop.hdl"
#endif

#ifndef _COM_SUN_STAR_UNO_TYPE_HXX_
#include "com/sun/star/uno/Type.hxx"
#endif
#ifndef INCLUDED_CPPU_UNOTYPE_HXX
#include "cppu/unotype.hxx"
#endif
#ifndef _SAL_TYPES_H_
#include "sal/types.h"
#endif
#ifndef _TYPELIB_TYPECLASS_H_
#include "typelib/typeclass.h"
#endif
#ifndef _TYPELIB_TYPEDESCRIPTION_H_
#include "typelib/typedescription.h"
#endif

namespace com { namespace sun { namespace star { namespace text {

inline GraphicCrop::GraphicCrop() SAL_THROW( () )
    : Top(0)
    , Bottom(0)
    , Left(0)
    , Right(0)
{
}

inline GraphicCrop::GraphicCrop(const ::sal_Int32& Top_, const ::sal_Int32& Bottom_, const ::sal_Int32& Left_, const ::sal_Int32& Right_) SAL_THROW( () )
    : Top(Top_)
    , Bottom(Bottom_)
    , Left(Left_)
    , Right(Right_)
{
}

} } } }

namespace com { namespace sun { namespace star { namespace text {

inline ::com::sun::star::uno::Type const & cppu_detail_getUnoType(::com::sun::star::text::GraphicCrop const *) {
    //TODO: On certain platforms with weak memory models, the following code can result in some threads observing that the_type points to garbage
    static ::typelib_TypeDescriptionReference * the_type = 0;
    if (the_type == 0) {
        ::typelib_static_type_init(&the_type, typelib_TypeClass_STRUCT, "com.sun.star.text.GraphicCrop");
    }
    return *reinterpret_cast< ::com::sun::star::uno::Type * >(&the_type);
};

} } } }

inline ::com::sun::star::uno::Type const & SAL_CALL getCppuType(::com::sun::star::text::GraphicCrop const *) SAL_THROW(()) {
    return ::cppu::UnoType< ::com::sun::star::text::GraphicCrop >::get();
}

#endif // _COM_SUN_STAR_TEXT_GRAPHICCROP_HPP_
